<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>清除全部</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>收起</translation>
    </message>
    <message>
        <source>More</source>
        <translation>更多</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>没有最近的通知</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>通知中心</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>清除全部</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>折叠</translation>
    </message>
    <message>
        <source>More</source>
        <translation>更多</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>取消置顶</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>置顶</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>通知设置</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation>清除全部</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>刚刚</translation>
    </message>
</context>
</TS>